@@ -1,7 +1,7 @@
 """
 Type annotations for codestar-notifications service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/literals/)
 
 Usage::
 
@@ -29,7 +29,9 @@ __all__ = (
     "ListTargetsPaginatorName",
     "NotificationRuleStatusType",
     "TargetStatusType",
+    "CodeStarNotificationsServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -45,6 +47,7 @@ ListTargetsFilterNameType = Literal["TARGET_ADDRESS", "TARGET_STATUS", "TARGET_T
 ListTargetsPaginatorName = Literal["list_targets"]
 NotificationRuleStatusType = Literal["DISABLED", "ENABLED"]
 TargetStatusType = Literal["ACTIVE", "DEACTIVATED", "INACTIVE", "PENDING", "UNREACHABLE"]
+CodeStarNotificationsServiceName = Literal["codestar-notifications"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -78,6 +81,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -332,4 +336,16 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_event_types", "list_notification_rules", "list_targets"]
