@@ -1,7 +1,7 @@
 """
 Type annotations for codestar-notifications service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/type_defs/)
 
 Usage::
 
@@ -13,7 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Mapping, Sequence
+from typing import Dict, List, Mapping, Sequence
+
+from typing_extensions import NotRequired
 
 from .literals import (
     DetailTypeType,
@@ -40,14 +42,17 @@ __all__ = (
     "DescribeNotificationRuleResultTypeDef",
     "EventTypeSummaryTypeDef",
     "ListEventTypesFilterTypeDef",
+    "ListEventTypesRequestListEventTypesPaginateTypeDef",
     "ListEventTypesRequestRequestTypeDef",
     "ListEventTypesResultTypeDef",
     "ListNotificationRulesFilterTypeDef",
+    "ListNotificationRulesRequestListNotificationRulesPaginateTypeDef",
     "ListNotificationRulesRequestRequestTypeDef",
     "ListNotificationRulesResultTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResultTypeDef",
     "ListTargetsFilterTypeDef",
+    "ListTargetsRequestListTargetsPaginateTypeDef",
     "ListTargetsRequestRequestTypeDef",
     "ListTargetsResultTypeDef",
     "NotificationRuleSummaryTypeDef",
@@ -181,6 +186,15 @@ ListEventTypesFilterTypeDef = TypedDict(
     },
 )
 
+ListEventTypesRequestListEventTypesPaginateTypeDef = TypedDict(
+    "ListEventTypesRequestListEventTypesPaginateTypeDef",
+    {
+        "Filters": Sequence["ListEventTypesFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListEventTypesRequestRequestTypeDef = TypedDict(
     "ListEventTypesRequestRequestTypeDef",
     {
@@ -208,6 +222,15 @@ ListNotificationRulesFilterTypeDef = TypedDict(
     },
 )
 
+ListNotificationRulesRequestListNotificationRulesPaginateTypeDef = TypedDict(
+    "ListNotificationRulesRequestListNotificationRulesPaginateTypeDef",
+    {
+        "Filters": Sequence["ListNotificationRulesFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListNotificationRulesRequestRequestTypeDef = TypedDict(
     "ListNotificationRulesRequestRequestTypeDef",
     {
@@ -250,6 +273,15 @@ ListTargetsFilterTypeDef = TypedDict(
     },
 )
 
+ListTargetsRequestListTargetsPaginateTypeDef = TypedDict(
+    "ListTargetsRequestListTargetsPaginateTypeDef",
+    {
+        "Filters": Sequence["ListTargetsFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListTargetsRequestRequestTypeDef = TypedDict(
     "ListTargetsRequestRequestTypeDef",
     {
@@ -294,7 +326,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
